@@ -19,6 +19,10 @@ class Atmosphere
  public:
     Atmosphere() :
         height(0.0f),
+        lowerColor(0.0f, 0.0f, 0.0f),
+        upperColor(0.0f, 0.0f, 0.0f),
+        skyColor(0.0f, 0.0f, 0.0f),
+        sunsetColor(1.0f, 0.6f, 0.5f),
         cloudHeight(0.0f),
         cloudSpeed(0.0f),
         cloudTexture() {};
@@ -28,6 +32,7 @@ class Atmosphere
     Color lowerColor;
     Color upperColor;
     Color skyColor;
+    Color sunsetColor;
     float cloudHeight;
     float cloudSpeed;
     MultiResTexture cloudTexture;
