@@ -1,14 +1,14 @@
 // body.h
 //
-// Copyright (C) 2001 Chris Laurel <claurel@shatters.net>
+// Copyright (C) 2001-2004 Chris Laurel <claurel@shatters.net>
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
 // as published by the Free Software Foundation; either version 2
 // of the License, or (at your option) any later version.
 
-#ifndef _BODY_H_
-#define _BODY_H_
+#ifndef _CELENGINE_BODY_H_
+#define _CELENGINE_BODY_H_
 
 #include <string>
 #include <vector>
@@ -19,7 +19,7 @@
 #include <celengine/orbit.h>
 #include <celengine/star.h>
 #include <celengine/location.h>
-#include <celengine/astro.h>
+#include <celengine/rotation.h>
 
 
 class Body;
@@ -47,7 +47,7 @@ class PlanetarySystem
     typedef bool (*TraversalFunc)(Body*, void*);
 
     bool traverse(TraversalFunc, void*) const;
-    Body* find(std::string, bool deepSearch = false) const;
+    Body* find(std::string, bool deepSearch = false, bool i18n = false) const;
     std::vector<std::string> getCompletion(const std::string& _name, bool rec = true) const;
 
  private:
@@ -57,20 +57,6 @@ class PlanetarySystem
 };
 
 
-class RotationElements
-{
- public:
-    RotationElements();
-
-    float period;        // sidereal rotation period
-    float offset;        // rotation at epoch
-    double epoch;
-    float obliquity;     // tilt of rotation axis w.r.t. ecliptic
-    float ascendingNode; // long. of ascending node of equator on the ecliptic
-    float precessionRate; // rate of precession of rotation axis in rads/day
-};
-
-
 class RingSystem 
 {
  public:
@@ -109,7 +95,7 @@ class Body
     };
 
     PlanetarySystem* getSystem() const;
-    std::string getName() const;
+    std::string getName(bool i18n = false) const;
     void setName(const std::string);
     Orbit* getOrbit() const;
     void setOrbit(Orbit*);
@@ -151,12 +137,17 @@ class Body
 
     float getLuminosity(const Star& sun,
                         float distanceFromSun) const;
+    float getLuminosity(float sunLuminosity,
+                        float distanceFromSun) const;
     float getApparentMagnitude(const Star& sun,
                                float distanceFromSun,
                                float distanceFromViewer) const;
     float getApparentMagnitude(const Star& sun,
                                const Vec3d& sunPosition,
                                const Vec3d& viewerPosition) const;
+    float getApparentMagnitude(float sunLuminosity,
+                               const Vec3d& sunPosition,
+                               const Vec3d& viewerPosition) const;
 
     Mat4d getLocalToHeliocentric(double) const;
     Point3d getHeliocentricPosition(double) const;
@@ -179,11 +170,12 @@ class Body
 
     std::vector<Location*>* getLocations() const;
     void addLocation(Location*);
-    Location* findLocation(const std::string&) const;
+    Location* findLocation(const std::string&, bool i18n = false) const;
     void computeLocations();
 
  private:
     std::string name;
+    std::string i18nName;
 
     PlanetarySystem* system;
     Orbit* orbit;
@@ -218,4 +210,4 @@ class Body
     mutable bool locationsComputed;
 };
 
-#endif // _BODY_H_
+#endif // _CELENGINE_BODY_H_
