@@ -10,6 +10,8 @@
 #ifndef _CELESTIA_H_
 #define _CELESTIA_H_
 
+#ifdef _WIN32
+
 #if _MSC_VER >= 1000
 // Make VC shut up about long variable names from templates
 #pragma warning(disable : 4786)
@@ -19,6 +21,8 @@
 #define BROKEN_FRIEND_TEMPLATES
 #endif // _MSC_VER
 
+#endif // _WIN32
+
 #define HAVE_SSTREAM
 #ifdef __GNUC__
 #undef HAVE_SSTREAM
@@ -26,7 +30,9 @@
 #endif // __GNUC__
 
 #ifndef _WIN32
+#ifndef MACOSX_PB
 #include <config.h>
+#endif /* MACOSX_PB */
 #endif /* _WIN32 */
 
 #endif // _CELESTIA_H_
