@@ -27,12 +27,14 @@
 #include <celengine/astro.h>
 #include "astro.h"
 #include "cmdparser.h"
+#include "glcontext.h"
 
 using namespace std;
 
 
 static int parseRenderFlags(string);
 static int parseLabelFlags(string);
+static int parseOrbitFlags(string);
 
 CommandParser::CommandParser(istream& in)
 {
@@ -318,6 +320,10 @@ Command* CommandParser::parseCommand()
     {
         cmd = new CommandCancel();
     }
+    else if (commandName == "exit")
+    {
+        cmd = new CommandExit();
+    }
     else if (commandName == "print")
     {
         string text;
@@ -524,6 +530,19 @@ Command* CommandParser::parseCommand()
 
         cmd = new CommandLabels(setFlags, clearFlags);
     }
+    else if (commandName == "orbitflags")
+    {
+        int setFlags = 0;
+        int clearFlags = 0;
+        string s;
+
+        if (paramList->getString("set", s))
+            setFlags = parseOrbitFlags(s);
+        if (paramList->getString("clear", s))
+            clearFlags = parseOrbitFlags(s);
+
+        cmd = new CommandOrbitFlags(setFlags, clearFlags);
+    }
     else if (commandName == "setvisibilitylimit")
     {
         double mag = 6.0;
@@ -586,6 +605,33 @@ Command* CommandParser::parseCommand()
     {
         cmd = new CommandUnmarkAll();
     }
+    else if (commandName == "capture")
+    {
+        string type, filename;
+        paramList->getString("type", type);
+        paramList->getString("filename", filename);
+		
+        cmd = new CommandCapture(type, filename);
+    }
+    else if (commandName == "renderpath")
+    {
+        GLContext::GLRenderPath glcpath = GLContext::GLPath_Basic;
+        string path;
+        paramList->getString("path", path);
+
+        if (compareIgnoringCase(path, "basic") == 0)
+            glcpath = GLContext::GLPath_Basic;
+        else if (compareIgnoringCase(path, "multitexture") == 0)
+            glcpath = GLContext::GLPath_Multitexture;
+        else if (compareIgnoringCase(path, "vp") == 0)
+            glcpath = GLContext::GLPath_DOT3_ARBVP;
+        else if (compareIgnoringCase(path, "vp-nv") == 0)
+            glcpath = GLContext::GLPath_NvCombiner_ARBVP;
+        else if (compareIgnoringCase(path, "glsl") == 0)
+            glcpath = GLContext::GLPath_GLSL;
+	
+        cmd = new CommandRenderPath(glcpath);
+    }
     else
     {
         error("Unknown command name '" + commandName + "'");
@@ -622,6 +668,8 @@ int parseRenderFlags(string s)
                 flags |= Renderer::ShowDiagrams;
             else if (compareIgnoringCase(name, "galaxies") == 0)
                 flags |= Renderer::ShowGalaxies;
+            else if (compareIgnoringCase(name, "nebulae") == 0)
+                flags |= Renderer::ShowNebulae;
             else if (compareIgnoringCase(name, "planets") == 0)
                 flags |= Renderer::ShowPlanets;
             else if (compareIgnoringCase(name, "stars") == 0)
@@ -708,3 +756,45 @@ int parseLabelFlags(string s)
 
     return flags;
 }
+
+
+int parseOrbitFlags(string s)
+{
+#ifdef HAVE_SSTREAM    
+    istringstream in(s);
+#else
+    istrstream in(s.c_str());
+#endif
+    Tokenizer tokenizer(&in);
+    int flags = 0;
+
+    Tokenizer::TokenType ttype = tokenizer.nextToken();
+    while (ttype != Tokenizer::TokenEnd)
+    {
+        if (ttype == Tokenizer::TokenName)
+        {
+            string name = tokenizer.getNameValue();
+            if (compareIgnoringCase(name, "planet") == 0)
+                flags |= Body::Planet;
+            else if (compareIgnoringCase(name, "moon") == 0)
+                flags |= Body::Moon;
+            else if (compareIgnoringCase(name, "asteroid") == 0)
+                flags |= Body::Asteroid;
+            else if (compareIgnoringCase(name, "comet") == 0)
+                flags |= Body::Comet;
+            else if (compareIgnoringCase(name, "spacecraft") == 0)
+                flags |= Body::Spacecraft;
+
+            ttype = tokenizer.nextToken();
+            if (ttype == Tokenizer::TokenBar)
+                ttype = tokenizer.nextToken();
+        }
+        else
+        {
+            DPRINTF(0, "Command Parser: error parsing orbit flags\n");
+            return 0;
+        }
+    }
+
+    return flags;
+}
