@@ -9,6 +9,12 @@
 #define APIENTRY
 #endif
 
+#ifndef GL_ARB_shader_objects
+/* GL types for handling shader object handles and characters */
+typedef char GLcharARB;		/* native character */
+typedef unsigned int GLhandleARB;	/* shader object handle */
+#endif
+
 /* EXT_rescale_normal defines from <GL/gl.h> */
 #ifndef GL_EXT_rescale_normal
 #define GL_EXT_rescale_normal 1
@@ -682,6 +688,13 @@ namespace glx
 #endif
 
 
+#ifndef GL_ARB_texture_env_dot3
+#define GL_ARB_texture_env_dot3
+#define GL_DOT3_RGB_ARB                   0x86AE
+#define GL_DOT3_RGBA_ARB                  0x86AF
+#endif
+
+
 /* ARB_vertex_program */
 #ifndef GL_ARB_vertex_program
 #define GL_ARB_vertex_program 1
@@ -915,8 +928,39 @@ namespace glx
 #define GL_PROGRAM_ERROR_STRING_NV        0x8874
 #endif /* GL_NV_fragment_program */
 
+#ifndef GL_ARB_vertex_shader
+#define GL_VERTEX_SHADER_ARB              0x8B31
+#define GL_MAX_VERTEX_UNIFORM_COMPONENTS_ARB 0x8B4A
+#define GL_MAX_VARYING_FLOATS_ARB         0x8B4B
+#define GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS_ARB 0x8B4C
+#define GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS_ARB 0x8B4D
+#define GL_OBJECT_ACTIVE_ATTRIBUTES_ARB   0x8B89
+#define GL_OBJECT_ACTIVE_ATTRIBUTE_MAX_LENGTH_ARB 0x8B8A
+#endif
+
+namespace glx
+{
+    typedef void (APIENTRY* PFNGLBINDATTRIBLOCATIONARBPROC) (GLhandleARB programObj, GLuint index, const GLcharARB *name);
+    typedef void (APIENTRY* PFNGLGETACTIVEATTRIBARBPROC) (GLhandleARB programObj, GLuint index, GLsizei maxLength, GLsizei *length, GLint *size, GLenum *type, GLcharARB *name);
+    typedef GLint (APIENTRY* PFNGLGETATTRIBLOCATIONARBPROC) (GLhandleARB programObj, const GLcharARB *name);
+
+    extern PFNGLBINDATTRIBLOCATIONARBPROC glBindAttribLocationARB;
+    extern PFNGLGETACTIVEATTRIBARBPROC glGetActiveAttribARB;
+    extern PFNGLGETATTRIBLOCATIONARBPROC glGetAttribLocationARB;
+};
+
+
+#ifndef GL_ARB_point_sprite
+#define GL_ARB_point_sprite 1
+#define GL_POINT_SPRITE_ARB               0x8861
+#define GL_COORD_REPLACE_ARB              0x8862
+#endif
+
+
 #ifndef GL_ARB_fragment_shader
 #define GL_ARB_fragment_shader 1
+#define GL_FRAGMENT_SHADER_ARB            0x8B30
+#define GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB 0x8B49
 #endif
 
 #ifndef GL_ARB_shading_language_100
