@@ -7,6 +7,8 @@
 // as published by the Free Software Foundation; either version 2
 // of the License, or (at your option) any later version.
 
+#include <fstream>
+
 #ifndef MACOSX
 #define JPEG_SUPPORT
 #define PNG_SUPPORT
@@ -54,6 +56,7 @@ extern "C" {
 #endif // MACOSX
 
 #include <celutil/debug.h>
+#include <celutil/util.h>
 #include <celutil/filetype.h>
 #include "gl.h"
 #include "glext.h"
@@ -61,7 +64,6 @@ extern "C" {
 
 #include <cassert>
 #include <iostream>
-#include <fstream>
 #include <algorithm>
 #include <cmath>
 
@@ -352,7 +354,7 @@ Image* LoadImageFromFile(const string& filename)
     ContentType type = DetermineFileType(filename);
     Image* img = NULL;
 
-    clog << "Loading image from file " << filename << '\n';
+    clog << _("Loading image from file ") << filename << '\n';
 
     switch (type)
     {
@@ -369,7 +371,7 @@ Image* LoadImageFromFile(const string& filename)
         img = LoadDDSImage(filename);
         break;
     default:
-        clog << filename << ": unrecognized or unsupported image file type.\n";
+        clog << filename << _(": unrecognized or unsupported image file type.\n");
         break;
     }
 
@@ -632,14 +634,14 @@ Image* LoadPNGImage(const string& filename)
     fp = fopen(filename.c_str(), "rb");
     if (fp == NULL)
     {
-        clog << "Error opening image file " << filename << '\n';
+        clog << _("Error opening image file ") << filename << '\n';
         return NULL;
     }
    
     fread(header, 1, sizeof(header), fp);
     if (png_sig_cmp((unsigned char*) header, 0, sizeof(header)))
     {
-        clog << "Error: " << filename << " is not a PNG file.\n";
+        clog << _("Error: ") << filename << _(" is not a PNG file.\n");
         fclose(fp);
         return NULL;
     }
@@ -666,7 +668,7 @@ Image* LoadPNGImage(const string& filename)
         if (img != NULL)
             delete img;
         png_destroy_read_struct(&png_ptr, &info_ptr, (png_infopp) NULL);
-        clog << "Error reading PNG image file " << filename << '\n';
+        clog << _("Error reading PNG image file ") << filename << '\n';
         return NULL;
     }
 
