@@ -19,6 +19,7 @@
 #include "rendcontext.h"
 #include "gl.h"
 #include "vecgl.h"
+#include "render.h"
 
 using namespace std;
 
@@ -29,6 +30,24 @@ Nebula::Nebula() :
 }
 
 
+const char* Nebula::getType() const
+{
+    return "Nebula";
+}
+
+
+void Nebula::setType(const string& typeStr)
+{
+}
+
+
+size_t Nebula::getDescription(char* buf, size_t bufLength) const
+{
+    // Should use snprintf, but it's not available on Windows
+    return sprintf(buf, _("%s"), getType());
+}
+
+
 ResourceHandle Nebula::getModel() const
 {
     return model;
@@ -54,7 +73,8 @@ bool Nebula::load(AssociativeArray* params, const string& resPath)
 }
 
 
-void Nebula::render(const Vec3f& offset,
+void Nebula::render(const GLContext&,
+                    const Vec3f& offset,
                     const Quatf& viewerOrientation,
                     float brightness,
                     float pixelSize)
@@ -83,3 +103,15 @@ void Nebula::render(const Vec3f& offset,
 
     glEnable(GL_BLEND);
 }
+
+
+unsigned int Nebula::getRenderMask() const
+{
+    return Renderer::ShowNebulae;
+}
+
+
+unsigned int Nebula::getLabelMask() const
+{
+    return Renderer::NebulaLabels;
+}
