@@ -18,6 +18,7 @@
 #include "meshmanager.h"
 #include "gl.h"
 #include "vecgl.h"
+#include "render.h"
 
 using namespace std;
 
@@ -27,6 +28,24 @@ OpenCluster::OpenCluster()
 }
 
 
+const char* OpenCluster::getType() const
+{
+    return "Cluster";
+}
+
+
+void OpenCluster::setType(const std::string& typeStr)
+{
+}
+
+
+size_t OpenCluster::getDescription(char* buf, size_t bufLength) const
+{
+    // Should use snprintf, but it's not available on Windows
+    return sprintf(buf, _("%s"), getType());
+}
+
+
 bool OpenCluster::load(AssociativeArray* params, const string& resPath)
 {
     // No parameters specific to open cluster, though a list of member stars
@@ -35,7 +54,8 @@ bool OpenCluster::load(AssociativeArray* params, const string& resPath)
 }
 
 
-void OpenCluster::render(const Vec3f& offset,
+void OpenCluster::render(const GLContext&,
+                         const Vec3f& offset,
                          const Quatf& viewerOrientation,
                          float brightness,
                          float pixelSize)
@@ -45,3 +65,15 @@ void OpenCluster::render(const Vec3f& offset,
     // would be to add an 'sky chart' mode, in which clusters are rendered as
     // circles.  
 }
+
+
+unsigned int OpenCluster::getRenderMask() const
+{
+    return Renderer::ShowOpenClusters;
+}
+
+
+unsigned int OpenCluster::getLabelMask() const
+{
+    return Renderer::OpenClusterLabels;
+}
