@@ -24,12 +24,27 @@ class OpenCluster : public DeepSkyObject
  public:
     OpenCluster();
 
+    virtual const char* getType() const;
+    virtual void setType(const std::string&);
+    virtual size_t getDescription(char* buf, size_t bufLength) const;
+
     virtual bool load(AssociativeArray*, const std::string&);
-    virtual void render(const Vec3f& offset,
+    virtual void render(const GLContext& context,
+                        const Vec3f& offset,
                         const Quatf& viewerOrientation,
                         float brightness,
                         float pixelSize);
 
+    virtual unsigned int getRenderMask() const;
+    virtual unsigned int getLabelMask() const;
+
+ public:
+    enum ClusterType {
+        Open          = 0,
+        Globular      = 1,
+        NotDefined    = 2
+    };
+
  private:
     // TODO: It could be very useful to have a list of stars that are members
     // of the cluster.
