@@ -1,6 +1,8 @@
-// solarsys.h
+// solarsys.cpp
 //
-// Copyright (C) 2001 Chris Laurel <claurel@shatters.net>
+// Copyright (C) 2001-2004 Chris Laurel <claurel@shatters.net>
+//
+// Solar system catalog parser.
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -23,15 +25,15 @@
 #include <cstdio>
 #include "astro.h"
 #include "parser.h"
-#include "customorbit.h"
 #include "texmanager.h"
 #include "meshmanager.h"
-#include "trajmanager.h"
 #include "universe.h"
 #include "multitexture.h"
+#include "parseobject.h"
 
 using namespace std;
 
+
 enum Disposition
 {
     AddObject,
@@ -75,7 +77,7 @@ enum Disposition
 
 static void errorMessagePrelude(const Tokenizer& tok)
 {
-    cerr << "Error in .ssc file (line " << tok.getLineNumber() << "): ";
+    cerr << _("Error in .ssc file (line ") << tok.getLineNumber() << "): ";
 }
 
 static void sscError(const Tokenizer& tok,
@@ -86,27 +88,6 @@ static void sscError(const Tokenizer& tok,
 }
 
 
-bool getDate(Hash* hash, const string& name, double& jd)
-{
-    // Check first for a number value representing a Julian date
-    if (hash->getNumber(name, jd))
-        return true;
-
-    string dateString;
-    if (hash->getString(name, dateString))
-    {
-        astro::Date date(1, 1, 1);
-        if (astro::parseDate(dateString, date))
-        {
-            jd = (double) date;
-            return true;
-        }
-    }
-
-    return false;
-}
-
-
 static Location* CreateLocation(Hash* locationData,
                                 Body* body)
 {
@@ -222,183 +203,6 @@ static void FillinSurface(Hash* surfaceData,
 }
 
 
-static EllipticalOrbit* CreateEllipticalOrbit(Hash* orbitData,
-                                              bool usePlanetUnits)
-{
-    // SemiMajorAxis and Period are absolutely required; everything
-    // else has a reasonable default.
-    double pericenterDistance = 0.0;
-    double semiMajorAxis = 0.0;
-    if (!orbitData->getNumber("SemiMajorAxis", semiMajorAxis))
-    {
-        if (!orbitData->getNumber("PericenterDistance", pericenterDistance))
-        {
-            DPRINTF(0, "SemiMajorAxis/PericenterDistance missing!  Skipping planet . . .\n");
-            return NULL;
-        }
-    }
-
-    double period = 0.0;
-    if (!orbitData->getNumber("Period", period))
-    {
-        DPRINTF(0, "Period missing!  Skipping planet . . .\n");
-        return NULL;
-    }
-
-    double eccentricity = 0.0;
-    orbitData->getNumber("Eccentricity", eccentricity);
-
-    double inclination = 0.0;
-    orbitData->getNumber("Inclination", inclination);
-
-    double ascendingNode = 0.0;
-    orbitData->getNumber("AscendingNode", ascendingNode);
-
-    double argOfPericenter = 0.0;
-    if (!orbitData->getNumber("ArgOfPericenter", argOfPericenter))
-    {
-        double longOfPericenter = 0.0;
-        if (orbitData->getNumber("LongOfPericenter", longOfPericenter))
-            argOfPericenter = longOfPericenter - ascendingNode;
-    }
-
-    double epoch = astro::J2000;
-    getDate(orbitData, "Epoch", epoch);
-
-    // Accept either the mean anomaly or mean longitude--use mean anomaly
-    // if both are specified.
-    double anomalyAtEpoch = 0.0;
-    if (!orbitData->getNumber("MeanAnomaly", anomalyAtEpoch))
-    {
-        double longAtEpoch = 0.0;
-        if (orbitData->getNumber("MeanLongitude", longAtEpoch))
-            anomalyAtEpoch = longAtEpoch - (argOfPericenter + ascendingNode);
-    }
-
-    if (usePlanetUnits)
-    {
-        semiMajorAxis = astro::AUtoKilometers(semiMajorAxis);
-        pericenterDistance = astro::AUtoKilometers(pericenterDistance);
-        period = period * 365.25f;
-    }
-
-    // If we read the semi-major axis, use it to compute the pericenter
-    // distance.
-    if (semiMajorAxis != 0.0)
-        pericenterDistance = semiMajorAxis * (1.0 - eccentricity);
-
-    // cout << " bounding radius: " << semiMajorAxis * (1.0 + eccentricity) << "km\n";
-
-    return new EllipticalOrbit(pericenterDistance,
-                               eccentricity,
-                               degToRad(inclination),
-                               degToRad(ascendingNode),
-                               degToRad(argOfPericenter),
-                               degToRad(anomalyAtEpoch),
-                               period,
-                               epoch);
-}
-
-
-static void FillinRotationElements(Hash* rotationData,
-                                   RotationElements& re,
-                                   float orbitalPeriod)
-{
-    // The default is synchronous rotation (rotation period == orbital period)
-    float period = orbitalPeriod;
-    if (rotationData->getNumber("RotationPeriod", period))
-        re.period = period / 24.0f;
-
-    float offset = 0.0f;
-    if (rotationData->getNumber("RotationOffset", offset))
-        re.offset = degToRad(offset);
-
-    rotationData->getNumber("RotationEpoch", re.epoch);
-
-    float obliquity = 0.0f;
-    if (rotationData->getNumber("Obliquity", obliquity))
-        re.obliquity = degToRad(obliquity);
-
-    float ascendingNode = 0.0f;
-    if (rotationData->getNumber("EquatorAscendingNode", ascendingNode))
-        re.ascendingNode = degToRad(ascendingNode);
-
-    float precessionRate = 0.0f;
-    if (rotationData->getNumber("PrecessionRate", precessionRate))
-        re.precessionRate = degToRad(precessionRate);
-}
-
-
-static Orbit* CreateOrbit(PlanetarySystem* system,
-                          Hash* planetData,
-                          const string& path,
-                          bool usePlanetUnits)
-{
-    Orbit* orbit = NULL;
-
-    string customOrbitName;
-    if (planetData->getString("CustomOrbit", customOrbitName))
-    {
-        orbit = GetCustomOrbit(customOrbitName);
-        if (orbit != NULL)
-        {
-            return orbit;
-        }
-        DPRINTF(0, "Could not find custom orbit named '%s'\n",
-                customOrbitName.c_str());
-    }
-
-    string sampOrbitFile;
-    if (planetData->getString("SampledOrbit", sampOrbitFile))
-    {
-        DPRINTF(1, "Attempting to load sampled orbit file '%s'\n",
-                sampOrbitFile.c_str());
-        ResourceHandle orbitHandle =
-            GetTrajectoryManager()->getHandle(TrajectoryInfo(sampOrbitFile, path));
-        orbit = GetTrajectoryManager()->find(orbitHandle);
-        if (orbit != NULL)
-        {
-            return orbit;
-        }
-        DPRINTF(0, "Could not load sampled orbit file '%s'\n",
-                sampOrbitFile.c_str());
-    }
-
-    Value* orbitDataValue = planetData->getValue("EllipticalOrbit");
-    if (orbitDataValue != NULL)
-    {
-        if (orbitDataValue->getType() != Value::HashType)
-        {
-            DPRINTF(0, "Object has incorrect elliptical orbit syntax.\n");
-            return NULL;
-        }
-        else
-        {
-            return CreateEllipticalOrbit(orbitDataValue->getHash(),
-                                         usePlanetUnits);
-        }
-    }
-
-    Vec3d longlat(0.0, 0.0, 0.0);
-    if (planetData->getVector("LongLat", longlat))
-    {
-        Body* parent = system->getPrimaryBody();
-        if (parent != NULL)
-        {
-            Vec3f pos = parent->planetocentricToCartesian((float) longlat.x, (float) longlat.y, (float) longlat.z);
-            Point3d posd(pos.x, pos.y, pos.z);
-            return new SynchronousOrbit(*parent, posd);
-        }
-        else
-        {
-            // TODO: Allow fixing objects to the surface of stars.
-        }
-        return NULL;
-    }
-
-    return NULL;
-}
-
 // Create a body (planet or moon) using the values from a hash
 // The usePlanetsUnits flags specifies whether period and semi-major axis
 // are in years and AU rather than days and kilometers
@@ -484,8 +288,8 @@ static Body* CreatePlanet(PlanetarySystem* system,
     double beginning   = -1.0e+50;
     double ending      =  1.0e+50;
     body->getLifespan(beginning, ending);
-    getDate(planetData, "Beginning", beginning);
-    getDate(planetData, "Ending", ending);
+    ParseDate(planetData, "Beginning", beginning);
+    ParseDate(planetData, "Ending", ending);
     body->setLifespan(beginning, ending);
 
     string infoURL;
@@ -511,7 +315,7 @@ static Body* CreatePlanet(PlanetarySystem* system,
     RotationElements re = body->getRotationElements();
     if (disposition != ModifyObject)
         re.period = (float) body->getOrbit()->getPeriod();
-    FillinRotationElements(planetData, re, (float) body->getOrbit()->getPeriod());
+    FillinRotationElements(planetData, re);
     body->setRotationElements(re);
 
     Surface surface;
@@ -619,9 +423,9 @@ static Body* CreatePlanet(PlanetarySystem* system,
 
                 double inner = 0.0, outer = 0.0;
                 if (ringsData->getNumber("Inner", inner))
-                    rings.innerRadius = inner;
+                    rings.innerRadius = (float) inner;
                 if (ringsData->getNumber("Outer", outer))
-                    rings.outerRadius = outer;
+                    rings.outerRadius = (float) outer;
 
                 Color color(1.0f, 1.0f, 1.0f);
                 if (ringsData->getColor("Color", color))
@@ -685,14 +489,14 @@ bool LoadSolarSystemObjects(istream& in,
             sscError(tokenizer, "object name expected");
             return false;
         }
-        string name = tokenizer.getStringValue();
+        string name = tokenizer.getStringValue().c_str();
 
         if (tokenizer.nextToken() != Tokenizer::TokenString)
         {
             sscError(tokenizer, "bad parent object name");
             return false;
         }
-        string parentName = tokenizer.getStringValue();
+        string parentName = tokenizer.getStringValue().c_str();
 
         Value* objectDataValue = parser.readValue();
         if (objectDataValue == NULL)
@@ -741,7 +545,7 @@ bool LoadSolarSystemObjects(istream& in,
             else
             {
                 errorMessagePrelude(tokenizer);
-                cerr << "parent body '" << parentName << "' of '" << name << "' not found.\n";
+                cerr << _("parent body '") << parentName << _("' of '") << name << _("' not found.\n");
             }
 
             if (parentSystem != NULL)
@@ -750,7 +554,7 @@ bool LoadSolarSystemObjects(istream& in,
                 if (existingBody && disposition == AddObject)
                 {
                     errorMessagePrelude(tokenizer);
-                    cerr << "warning duplicate definition of " <<
+                    cerr << _("warning duplicate definition of ") <<
                         parentName << " " <<  name << '\n';
                 }
                 
@@ -779,7 +583,7 @@ bool LoadSolarSystemObjects(istream& in,
             if (surface != NULL && parent.body() != NULL)
                 parent.body()->addAlternateSurface(name, surface);
             else
-                sscError(tokenizer, "bad alternate surface");
+                sscError(tokenizer, _("bad alternate surface"));
         }
         else if (itemType == "Location")
         {
@@ -793,13 +597,13 @@ bool LoadSolarSystemObjects(istream& in,
                 }
                 else
                 {
-                    sscError(tokenizer, "bad location");
+                    sscError(tokenizer, _("bad location"));
                 }
             }
             else
             {
                 errorMessagePrelude(tokenizer);
-                cerr << "parent body '" << parentName << "' of '" << name << "' not found.\n";
+                cerr << _("parent body '") << parentName << _("' of '") << name << _("' not found.\n");
             }
         }
     }
