@@ -13,19 +13,21 @@
 #include <celmath/vecmath.h>
 #include <celmath/intersect.h>
 #include <celutil/utf8.h>
+#include <cassert>
 #include "astro.h"
 #include "3dsmesh.h"
 #include "meshmanager.h"
 #include "universe.h"
 
+#define ANGULAR_RES 3.5e-6
+
 using namespace std;
 
-#define ANGULAR_RES 3.5e-6
 
 Universe::Universe() :
     starCatalog(NULL),
     solarSystemCatalog(NULL),
-    deepSkyCatalog(NULL),
+    dsoCatalog(NULL),
     asterisms(NULL),
     /*boundaries(NULL),*/
     markers(NULL)
@@ -62,14 +64,14 @@ void Universe::setSolarSystemCatalog(SolarSystemCatalog* catalog)
 }
 
 
-DeepSkyCatalog* Universe::getDeepSkyCatalog() const
+DSODatabase* Universe::getDSOCatalog() const
 {
-    return deepSkyCatalog;
+    return dsoCatalog;
 }
 
-void Universe::setDeepSkyCatalog(DeepSkyCatalog* catalog)
+void Universe::setDSOCatalog(DSODatabase* catalog)
 {
-    deepSkyCatalog = catalog;
+    dsoCatalog = catalog;
 }
 
 
@@ -260,6 +262,33 @@ void ClosestStarFinder::process(const Star& star, float distance, float appMag)
 }
 
 
+class NearStarFinder : public StarHandler
+{
+public:
+    NearStarFinder(float _maxDistance, vector<const Star*>& nearStars);
+    ~NearStarFinder() {};
+    void process(const Star& star, float distance, float appMag);
+
+private:
+    float maxDistance;
+    vector<const Star*>& nearStars;
+};
+
+NearStarFinder::NearStarFinder(float _maxDistance,
+                               vector<const Star*>& _nearStars) :
+    maxDistance(_maxDistance),
+    nearStars(_nearStars)
+{
+}
+
+void NearStarFinder::process(const Star& star, float distance, float appMag)
+{
+    if (distance < maxDistance)
+        nearStars.push_back(&star);
+}
+
+
+
 struct PlanetPickInfo
 {
     double sinAngle2Closest;
@@ -291,7 +320,9 @@ static bool ApproxPlanetPickTraversal(Body* body, void* info)
     
     if ((pickInfo->atanTolerance > ANGULAR_RES ? pickInfo->atanTolerance: 
         ANGULAR_RES) > appOrbitRadius)
+    {
         return true;
+    }
 
     bodyDir.normalize();
     Vec3d bodyMiss = bodyDir - pickInfo->pickRay.direction;
@@ -401,9 +432,18 @@ Selection Universe::pickPlanet(SolarSystem& solarSystem,
 	              sin(tolerance/2.0) : ANGULAR_RES);
     PlanetPickInfo pickInfo;
 
-    // Transform the pick direction
-    pickInfo.pickRay = Ray3d(astro::heliocentricPosition(origin, 
-    solarSystem.getCenter()), Vec3d(direction.x, direction.y, direction.z));
+    Star* star = solarSystem.getStar();
+    assert(star != NULL);
+
+    // Transform the pick ray origin into astrocentric coordinates
+    UniversalCoord starPos = star->getPosition(when);
+    Vec3d v = origin - starPos;
+    Point3d astrocentricOrigin(astro::microLightYearsToKilometers(v.x),
+                               astro::microLightYearsToKilometers(v.y),
+                               astro::microLightYearsToKilometers(v.z));
+
+    pickInfo.pickRay = Ray3d(astrocentricOrigin,
+                             Vec3d(direction.x, direction.y, direction.z));
                              
     pickInfo.sinAngle2Closest = 1.0;
     pickInfo.closestDistance = 1.0e50;
@@ -462,7 +502,7 @@ Selection Universe::pickPlanet(SolarSystem& solarSystem,
 class StarPicker : public StarHandler
 {
 public:
-    StarPicker(const Point3f&, const Vec3f&, float);
+    StarPicker(const Point3f&, const Vec3f&, double, float);
     ~StarPicker() {};
 
     void process(const Star&, float, float);
@@ -472,27 +512,56 @@ public:
     Point3f pickOrigin;
     Vec3f pickRay;
     double sinAngle2Closest;
+    double when;
 };
 
-StarPicker::StarPicker(const Point3f& _pickOrigin, const Vec3f& _pickRay,
+StarPicker::StarPicker(const Point3f& _pickOrigin,
+                       const Vec3f& _pickRay,
+                       double _when,
                        float angle) :
     pickedStar(NULL),
     pickOrigin(_pickOrigin),
     pickRay(_pickRay),
     sinAngle2Closest(sin(angle/2.0) > ANGULAR_RES ? sin(angle/2.0) : 
-                                      ANGULAR_RES )
+                                                    ANGULAR_RES ),
+    when(_when)
 {
 }
 
 void StarPicker::process(const Star& star, float distance, float appMag)
 {
-    Vec3f starDir = star.getPosition() - pickOrigin;
+    Vec3f relativeStarPos = star.getPosition() - pickOrigin;
+    Vec3f starDir = relativeStarPos;
     starDir.normalize();
 
+    double sinAngle2 = 0.0;
+
+    // Stars with orbits need special handling
+    float orbitalRadius = star.getOrbitalRadius();
+    if (orbitalRadius != 0.0f)
+    {
+        float distance;
+
+        // Check for an intersection with orbital bounding sphere; if there's
+        // no intersection, then just use normal calculation.  We actually test
+        // intersection with a larger sphere to make sure we don't miss a star
+        // right on the edge of the sphere.
+        if (testIntersection(Ray3f(Point3f(0.0f, 0.0f, 0.0f), pickRay),
+                             Spheref(Point3f(0.0f, 0.0f, 0.0f) + relativeStarPos,
+                                     orbitalRadius * 2.0f),
+                             distance))
+        {
+            Point3d starPos = star.getPosition(when);
+            starDir = Vec3f((float) (starPos.x * 1.0e-6 - pickOrigin.x),
+                            (float) (starPos.y * 1.0e-6 - pickOrigin.y),
+                            (float) (starPos.z * 1.0e-6 - pickOrigin.z));
+            starDir.normalize();
+        }
+    }
+
     Vec3f starMiss = starDir - pickRay;
     Vec3d sMd = Vec3d(starMiss.x, starMiss.y, starMiss.z); 
-    
-    double sinAngle2 = sqrt(sMd * sMd)/2.0;
+    sinAngle2 = sqrt(sMd * sMd)/2.0;
 
     if (sinAngle2 <= sinAngle2Closest)
     {
@@ -507,6 +576,7 @@ class CloseStarPicker : public StarHandler
 public:
     CloseStarPicker(const UniversalCoord& pos,
                     const Vec3f& dir,
+                    double t,
                     float _maxDistance,
                     float angle);
     ~CloseStarPicker() {};
@@ -515,6 +585,7 @@ public:
 public:
     UniversalCoord pickOrigin;
     Vec3f pickDir;
+    double now;
     float maxDistance;
     const Star* closestStar;
     float closestDistance;
@@ -524,10 +595,12 @@ public:
 
 CloseStarPicker::CloseStarPicker(const UniversalCoord& pos,
                                  const Vec3f& dir,
+                                 double t,
                                  float _maxDistance,
                                  float angle) :
     pickOrigin(pos),
     pickDir(dir),
+    now(t),
     maxDistance(_maxDistance),
     closestStar(NULL),
     closestDistance(0.0f),
@@ -543,8 +616,9 @@ void CloseStarPicker::process(const Star& star,
     if (lowPrecDistance > maxDistance)
         return;
 
-    Point3d hPos = astro::heliocentricPosition(pickOrigin, star.getPosition());
-    Vec3f starDir((float) -hPos.x, (float) -hPos.y, (float) -hPos.z);
+    Vec3d hPos = (star.getPosition(now) - pickOrigin) * 
+        astro::microLightYearsToKilometers(1.0);
+    Vec3f starDir((float) hPos.x, (float) hPos.y, (float) hPos.z);
     float distance = 0.0f;
 
      if (testIntersection(Ray3f(Point3f(0, 0, 0), pickDir),
@@ -585,6 +659,7 @@ void CloseStarPicker::process(const Star& star,
 
 Selection Universe::pickStar(const UniversalCoord& origin,
                              const Vec3f& direction,
+                             double when,
                              float faintestMag,
                              float tolerance)
 {
@@ -599,7 +674,7 @@ Selection Universe::pickStar(const UniversalCoord& origin,
     // precision pick test isn't reliable close to a star and the high
     // precision test isn't nearly fast enough to use on our database of
     // over 100k stars.
-    CloseStarPicker closePicker(origin, direction, 1.0f, tolerance);
+    CloseStarPicker closePicker(origin, direction, when, 1.0f, tolerance);
     starCatalog->findCloseStars(closePicker, o, 1.0f);
     if (closePicker.closestStar != NULL)
         return Selection(const_cast<Star*>(closePicker.closestStar));
@@ -627,7 +702,7 @@ Selection Universe::pickStar(const UniversalCoord& origin,
         axis.normalize();
         rotation.setAxisAngle(axis, (float) (2.0 * asin(sinAngle2)));
     }
-    StarPicker picker(o, direction, tolerance);
+    StarPicker picker(o, direction, when, tolerance);
     starCatalog->findVisibleStars(picker,
                                   o,
                                   rotation,
@@ -640,39 +715,172 @@ Selection Universe::pickStar(const UniversalCoord& origin,
 }
 
 
+class DSOPicker : public DSOHandler
+{
+public:
+    DSOPicker(const Point3d&, const Vec3d&, float);
+    ~DSOPicker() {};
+
+    void process(DeepSkyObject* const &, double, float);
+
+public:
+    const DeepSkyObject* pickedDSO;
+    Point3d pickOrigin;
+    Vec3d   pickDir;
+    double  sinAngle2Closest;
+};
+
+
+DSOPicker::DSOPicker(const Point3d& pickOrigin,
+                     const Vec3d&   pickDir,
+                     float angle) :
+    pickedDSO       (NULL),
+    pickOrigin      (pickOrigin),
+    pickDir         (pickDir),
+    sinAngle2Closest(sin(angle/2.0) > ANGULAR_RES ? sin(angle/2.0) :
+                                                    ANGULAR_RES )
+{
+}
+
+
+void DSOPicker::process(DeepSkyObject* const & dso, double distance, float appMag)
+{
+    Vec3d relativeDSOPos = dso->getPosition() - pickOrigin;
+    Vec3d dsoDir = relativeDSOPos;
+    dsoDir.normalize();
+
+    double sinAngle2 = 0.0;
+
+    double distance2;
+    if (testIntersection(Ray3d(Point3d(0.0, 0.0, 0.0), pickDir),
+                         Sphered(Point3d(0.0, 0.0, 0.0) + relativeDSOPos, (double) dso->getRadius()), distance2))
+    {
+        Point3d dsoPos = dso->getPosition();
+        dsoDir         = Vec3d(dsoPos.x * 1.0e-6 - pickOrigin.x,
+                               dsoPos.y * 1.0e-6 - pickOrigin.y,
+                               dsoPos.z * 1.0e-6 - pickOrigin.z);
+        dsoDir.normalize();
+    }
+
+    Vec3d dsoMissd   = dsoDir - Vec3d(pickDir.x, pickDir.y, pickDir.z);
+    sinAngle2        = sqrt(dsoMissd * dsoMissd)/2.0;
+
+    if (sinAngle2 <= sinAngle2Closest)
+    {
+        sinAngle2Closest = sinAngle2 > ANGULAR_RES ? sinAngle2 : ANGULAR_RES;
+        pickedDSO        = dso;
+    }
+}
+
+
+class CloseDSOPicker : public DSOHandler
+{
+public:
+    CloseDSOPicker(const Point3d& pos,
+                   const Vec3d& dir,
+                   double maxDistance,
+                   float angle);
+    ~CloseDSOPicker() {};
+
+    void process(DeepSkyObject* const & dso, double distance, float appMag);
+
+public:
+    Point3d              pickOrigin;
+    Vec3d                pickDir;
+    double maxDistance;
+    const DeepSkyObject* closestDSO;
+    double closestDistance;
+};
+
+
+CloseDSOPicker::CloseDSOPicker(const Point3d& pos,
+                               const Vec3d& dir,
+                               double                maxDistance,
+                               float angle) :
+    pickOrigin      (pos),
+    pickDir         (dir),
+    maxDistance     (maxDistance),
+    closestDSO      (NULL),
+    closestDistance(1.0e32)
+{
+}
+
+
+void CloseDSOPicker::process(DeepSkyObject* const & dso,
+                             double distance,
+                             float appMag)
+{
+
+    if (distance > maxDistance)
+        return;
+
+    double  distance2  = 0.0;
+    if (testIntersection(Ray3d(pickOrigin, pickDir),
+                         Sphered(dso->getPosition(), (double) dso->getRadius()),
+                         distance2))
+    {
+        // Don't select the object the observer is currently in:
+        if (pickOrigin.distanceTo(dso->getPosition()) > dso->getRadius() &&
+            distance2 < closestDistance)
+        {
+            closestDSO = dso;
+            closestDistance  = distance2;
+        }
+    }
+}
+
+
 Selection Universe::pickDeepSkyObject(const UniversalCoord& origin,
                                       const Vec3f& direction,
                                       float faintestMag,
                                       float tolerance)
 {
-    Selection sel;
-    Point3d p = (Point3d) origin;
-    Ray3d pickRay(Point3d(p.x * 1e-6, p.y * 1e-6, p.z * 1e-6),
-                  Vec3d(direction.x, direction.y, direction.z));
-    double closestDistance = 1.0e30;
+    Point3d orig = (Point3d) origin;
+    orig.x *= 1e-6;
+    orig.y *= 1e-6;
+    orig.z *= 1e-6;
 
-    if (deepSkyCatalog != NULL)
+    Vec3d dir   = Vec3d(direction.x, direction.y, direction.z);
+
+    CloseDSOPicker closePicker(orig, dir, 1e9, tolerance);
+
+    dsoCatalog->findCloseDSOs(closePicker, orig, 1e9);
+    if (closePicker.closestDSO != NULL)
     {
-        for (DeepSkyCatalog::const_iterator iter = deepSkyCatalog->begin();
-             iter != deepSkyCatalog->end(); iter++)
-        {
-            double distance = 0.0;
-            if (testIntersection(pickRay, 
-                                 Sphered((*iter)->getPosition(), (*iter)->getRadius()),
-                                 distance))
-            {
-                // Don't select an object that contains the origin
-                if (pickRay.origin.distanceTo((*iter)->getPosition()) > (*iter)->getRadius() &&
-                    distance < closestDistance)
-                {
-                    closestDistance = distance;
-                    sel = Selection(*iter);
-                }
-            }
-        }
+        return Selection(const_cast<DeepSkyObject*>(closePicker.closestDSO));
     }
 
-    return sel;
+    Quatf rotation;
+    Vec3d n(0, 0, -1);
+    Vec3d Miss       = n - dir;
+    double sinAngle2 = sqrt(Miss * Miss)/2.0;
+
+    if (sinAngle2 <= ANGULAR_RES)
+    {
+        rotation.setAxisAngle(Vec3f(1, 0, 0), 0);
+    }
+    else if (sinAngle2 >= 1.0 - 0.5 * ANGULAR_RES * ANGULAR_RES)
+    {
+        rotation.setAxisAngle(Vec3f(1, 0, 0), (float) PI);
+    }
+    else
+    {
+        Vec3f axis = direction ^ Vec3f((float)n.x, (float)n.y, (float)n.z);
+        axis.normalize();
+        rotation.setAxisAngle(axis, (float) (2.0 * asin(sinAngle2)));
+    }
+
+    DSOPicker picker(orig, dir, tolerance);
+    dsoCatalog->findVisibleDSOs(picker,
+                                orig,
+                                rotation,
+                                tolerance,
+                                1.0f,
+                                faintestMag);
+    if (picker.pickedDSO != NULL)
+        return Selection(const_cast<DeepSkyObject*>(picker.pickedDSO));
+    else
+        return Selection();
 }
 
 
@@ -684,6 +892,25 @@ Selection Universe::pick(const UniversalCoord& origin,
 {
     Selection sel;
 
+    closeStars.clear();
+    getNearStars(origin, 1.0f, closeStars);
+    for (vector<const Star*>::const_iterator iter = closeStars.begin();
+         iter != closeStars.end(); iter++)
+    {
+        SolarSystem* solarSystem = getSolarSystem(*iter);
+        if (solarSystem != NULL)
+        {
+            sel = pickPlanet(*solarSystem,
+                             origin, direction,
+                             when,
+                             faintestMag,
+                             tolerance);
+            if (!sel.empty())
+                break;
+        }
+    }
+    
+#if 0
     SolarSystem* closestSolarSystem = getNearestSolarSystem(origin);
     if (closestSolarSystem != NULL)
     {
@@ -693,9 +920,10 @@ Selection Universe::pick(const UniversalCoord& origin,
                          faintestMag,
                          tolerance);
     }
+#endif
 
     if (sel.empty())
-        sel = pickStar(origin, direction, faintestMag, tolerance);
+        sel = pickStar(origin, direction, when, faintestMag, tolerance);
 
     if (sel.empty())
         sel = pickDeepSkyObject(origin, direction, faintestMag, tolerance);
@@ -706,7 +934,8 @@ Selection Universe::pick(const UniversalCoord& origin,
 
 // Search by name for an immediate child of the specified object.
 Selection Universe::findChildObject(const Selection& sel,
-                                    const string& name) const
+                                    const string& name,
+                                    bool i18n) const
 {
     switch (sel.getType())
     {
@@ -717,7 +946,7 @@ Selection Universe::findChildObject(const Selection& sel,
             {
                 PlanetarySystem* planets = sys->getPlanets();
                 if (planets != NULL)
-                    return Selection(planets->find(name, false));
+                    return Selection(planets->find(name, false, i18n));
             }
         }
         break;
@@ -728,13 +957,13 @@ Selection Universe::findChildObject(const Selection& sel,
             PlanetarySystem* sats = sel.body()->getSatellites();
             if (sats != NULL)
             {
-                Body* body = sats->find(name, false);
+                Body* body = sats->find(name, false, i18n);
                 if (body != NULL)
                     return Selection(body);
             }
 
             // If a satellite wasn't found, check this object's locations
-            Location* loc = sel.body()->findLocation(name);
+            Location* loc = sel.body()->findLocation(name, i18n);
             if (loc != NULL)
                 return Selection(loc);
         }
@@ -761,7 +990,8 @@ Selection Universe::findChildObject(const Selection& sel,
 // system.  For locations and planets, the context additionally includes
 // sibling or child locations, respectively.
 Selection Universe::findObjectInContext(const Selection& sel,
-                                        const string& name) const
+                                        const string& name,
+                                        bool i18n) const
 {
     Body* contextBody = NULL;
 
@@ -786,7 +1016,7 @@ Selection Universe::findObjectInContext(const Selection& sel,
         PlanetarySystem* planets = sys->getPlanets();
         if (planets != NULL)
         {
-            Body* body = planets->find(name, true);
+            Body* body = planets->find(name, true, i18n);
             if (body != NULL)
                 return Selection(body);
         }
@@ -795,7 +1025,7 @@ Selection Universe::findObjectInContext(const Selection& sel,
     // . . . and then locations.
     if (contextBody != NULL)
     {
-        Location* loc = contextBody->findLocation(name);
+        Location* loc = contextBody->findLocation(name, i18n);
         if (loc != NULL)
             return Selection(loc);
     }
@@ -812,25 +1042,26 @@ Selection Universe::findObjectInContext(const Selection& sel,
 //      to us to search.
 Selection Universe::find(const string& s,
                          Selection* contexts,
-                         int nContexts)
+                         int nContexts,
+                         bool i18n)
 {
-    if (deepSkyCatalog != NULL)
+    if (starCatalog != NULL)
     {
-        for (DeepSkyCatalog::const_iterator iter = deepSkyCatalog->begin();
-             iter != deepSkyCatalog->end(); iter++)
-        {
-            if (UTF8StringCompare((*iter)->getName(), s) == 0)
-                return Selection(*iter);
-        }
-    }
-
     Star* star = starCatalog->find(s);
     if (star != NULL)
         return Selection(star);
+    }
 
-    for (int i = 0; i < nContexts; i++)
+    if (dsoCatalog != NULL)
     {
-        Selection sel = findObjectInContext(contexts[i], s);
+        DeepSkyObject* dso = dsoCatalog->find(s);
+        if (dso != NULL)
+            return Selection(dso);
+    }
+
+    for (int i=0; i<nContexts; ++i)
+    {
+        Selection sel = findObjectInContext(contexts[i], s, i18n);
         if (!sel.empty())
             return sel;
     }
@@ -847,17 +1078,19 @@ Selection Universe::find(const string& s,
 // in which the user is currently located.
 Selection Universe::findPath(const string& s,
                              Selection contexts[],
-                             int nContexts)
-{
+                             int nContexts,
+                             bool i18n)
+{ 
     string::size_type pos = s.find('/', 0);
 
     // No delimiter found--just do a normal find.
     if (pos == string::npos)
-        return find(s, contexts, nContexts);
+        return find(s, contexts, nContexts, i18n);
 
     // Find the base object
     string base(s, 0, pos);
-    Selection sel = find(base, contexts, nContexts);
+
+    Selection sel = find(base, contexts, nContexts, i18n);
 
     while (!sel.empty() && pos != string::npos)
     {
@@ -869,7 +1102,7 @@ Selection Universe::findPath(const string& s,
             len = nextPos - pos - 1;
         string name = string(s, pos + 1, len);
 
-        sel = findChildObject(sel, name);
+        sel = findChildObject(sel, name, i18n);
 
         pos = nextPos;
     }
@@ -878,26 +1111,26 @@ Selection Universe::findPath(const string& s,
 }
 
 
-std::vector<std::string> Universe::getCompletion(const string& s,
+vector<string> Universe::getCompletion(const string& s,
                                                  Selection* contexts,
                                                  int nContexts,
                                                  bool withLocations)
 {
-    std::vector<std::string> completion;
+    vector<string> completion;
 
-    // Solar bodies first
+    // Solar bodies first:
     for (int i = 0; i < nContexts; i++)
     {
         if (withLocations && contexts[i].getType() == Selection::Type_Body)
         {
-            std::vector<Location*>* locations = contexts[i].body()->getLocations();
+            vector<Location*>* locations = contexts[i].body()->getLocations();
             if (locations != NULL)
             {
                 for (vector<Location*>::const_iterator iter = locations->begin();
                      iter != locations->end(); iter++)
                 {
-                    if (!UTF8StringCompare(s, (*iter)->getName(), s.length()))
-                        completion.push_back((*iter)->getName());
+                    if (!UTF8StringCompare(s, (*iter)->getName(true), s.length()))
+                        completion.push_back((*iter)->getName(true));
                 }
             }
         }
@@ -908,71 +1141,73 @@ std::vector<std::string> Universe::getCompletion(const string& s,
             PlanetarySystem* planets = sys->getPlanets();
             if (planets != NULL)
             {
-                std::vector<std::string> bodies = planets->getCompletion(s);
+                vector<string> bodies = planets->getCompletion(s);
                 completion.insert(completion.end(),
                                   bodies.begin(), bodies.end());
             }
         }
     }
 
-    // Deep sky object
-    if (deepSkyCatalog != NULL)
-    {
-        for (DeepSkyCatalog::const_iterator iter = deepSkyCatalog->begin();
-             iter != deepSkyCatalog->end(); iter++)
+    // Deep sky objects:
+    if (dsoCatalog != NULL)
         {
-            if (UTF8StringCompare((*iter)->getName(), s, s.length()) == 0)
-                completion.push_back(Selection(*iter).getName());
-        }
+        vector<string> dsos  = dsoCatalog->getCompletion(s);
+        completion.insert(completion.end(), dsos.begin(), dsos.end());
     }
 
-    // finally stars;
-    std::vector<std::string> stars = starCatalog->getCompletion(s);
+    // and finally stars;
+    if (starCatalog != NULL)
+    {
+        vector<string> stars  = starCatalog->getCompletion(s);
     completion.insert(completion.end(), stars.begin(), stars.end());
+    }
 
     return completion;
 }
 
-std::vector<std::string> Universe::getCompletionPath(const string& s,
+
+vector<string> Universe::getCompletionPath(const string& s,
                                                      Selection* contexts,
                                                      int nContexts,
                                                      bool withLocations)
 {
-    std::vector<std::string> completion;
-    std::vector<std::string> locationCompletion;
-    
+    vector<string> completion;
+    vector<string> locationCompletion;
     string::size_type pos = s.rfind('/', s.length());
 
     if (pos == string::npos)
         return getCompletion(s, contexts, nContexts, withLocations);
 
     string base(s, 0, pos);
-    Selection sel = findPath(base, contexts, nContexts);
+    Selection sel = findPath(base, contexts, nContexts, true);
 
     if (sel.empty())
+    {
+        cerr << "nothing found" << endl;
         return completion;
+    }
 
     if (sel.getType() == Selection::Type_DeepSky)
     {
-        completion.push_back(sel.deepsky()->getName());
+        completion.push_back(dsoCatalog->getDSOName(sel.deepsky()));
         return completion;
     }
 
     PlanetarySystem* worlds = NULL;
     if (sel.getType() == Selection::Type_Body)
-    {
+    {cerr << "body found" << endl;
         worlds = sel.body()->getSatellites();
-        std::vector<Location*>* locations = sel.body()->getLocations();
+        vector<Location*>* locations = sel.body()->getLocations();
         if (locations != NULL && withLocations)
         {
             string search = s.substr(pos + 1);
             for (vector<Location*>::const_iterator iter = locations->begin();
                  iter != locations->end(); iter++)
             {
-                if (!UTF8StringCompare(search, (*iter)->getName(),
+                if (!UTF8StringCompare(search, (*iter)->getName(true),
                                        search.length()))
                 {
-                    locationCompletion.push_back((*iter)->getName());
+                    locationCompletion.push_back((*iter)->getName(true));
                 }
             }
         }
@@ -1003,3 +1238,15 @@ SolarSystem* Universe::getNearestSolarSystem(const UniversalCoord& position) con
     starCatalog->findCloseStars(closestFinder, lyPos, 1.0f);
     return getSolarSystem(closestFinder.closestStar);
 }
+
+
+void
+Universe::getNearStars(const UniversalCoord& position,
+                       float maxDistance,
+                       vector<const Star*>& nearStars) const
+{
+    Point3f pos = (Point3f) position;
+    Point3f lyPos(pos.x * 1.0e-6f, pos.y * 1.0e-6f, pos.z * 1.0e-6f);
+    NearStarFinder finder(1.0f, nearStars);
+    starCatalog->findCloseStars(finder, lyPos, maxDistance);
+}
