@@ -32,7 +32,7 @@
 #include <qpalette.h>
 #include <qfont.h>
 #include <qlineedit.h>
-#include <qvalidator.h> 
+#include <qvalidator.h>
 
 #include <qmenubar.h>
 #include <qpopupmenu.h>
@@ -77,11 +77,13 @@
 #include "celestialbrowser.h"
 #include "eclipsefinderdlg.h"
 #include "selectionpopup.h"
+#include "celsplashscreen.h"
 
 #include "celengine/glext.h"
 
 #define MENUMAXSIZE 100
 
+
 KdeApp* KdeApp::app=0;
 
 KBookmarkManager* KCelBookmarkManager::s_bookmarkManager;
@@ -95,13 +97,30 @@ static uint32 FilterOtherLocations = ~(Location::City |
                     Location::Vallis |
                     Location::Mare);
 
-KdeApp::KdeApp(QWidget *parent, const char *name) : KMainWindow(parent, name)
+KdeApp::KdeApp(std::string config, std::string dir, std::vector<std::string> extrasDirs, bool fullscreen, bool disableSplash) : KMainWindow(0, 0)
 {
-#if KDE_VERSION >= 0x030200 
-    QPixmap splash_pixmap(locate("appdata", "celestia-splash.jpg"));
-    KSplashScreen *splash = new KSplashScreen(splash_pixmap);
-    splash->show();
-    splash->message( i18n("Loading..."), Qt::AlignBottom | Qt::AlignAuto, QColor(255,255,255) );
+#if KDE_VERSION >= 0x030200
+    CelSplashScreen *splash = NULL;
+    if (!disableSplash) {
+        QStringList splashDirs = KGlobal::dirs()->findDirs("appdata", "splash");
+        QStringList images;
+        srandom(time(NULL));
+        for(QStringList::iterator i = splashDirs.begin(); i != splashDirs.end(); ++i) {
+            QDir d(*i);
+            d.setFilter(QDir::Files);
+            QStringList splashImages = d.entryList().grep(QRegExp("\\.(jpg|png)$", FALSE));
+            for(QStringList::iterator j = splashImages.begin(); j != splashImages.end(); ++j) {
+                images.append(*i + *j);
+            }
+        }
+        
+        if (images.size() > 0) {
+            int index = (int)(random()*1./RAND_MAX*images.size());
+            splash = new CelSplashScreen(images[index], this);
+        } else {
+            KMessageBox::queuedMessageBox(this, KMessageBox::Information, i18n("Something seems to be wrong with your installation of Celestia. The splash screen directory couldn't be found. \nStart-up will continue, but Celestia will probably be missing some data files and may not work correctly, please check your installation."));
+        }
+    }
 #endif
     
     appCore=new CelestiaCore();
@@ -123,8 +142,22 @@ KdeApp::KdeApp(QWidget *parent, const char *name) : KMainWindow(parent, name)
     setAcceptDrops(true);
 
     // Create our OpenGL widget
+    if ( (dir.length() > 1 ? chdir(dir.c_str()):chdir(CONFIG_DATA_DIR)) == -1)
+    {
+        ::std::cout << "Cannot chdir to '" << CONFIG_DATA_DIR << "', probably due to improper installation" << ::std::endl;
+	exit(1);
+    }
     glWidget = new KdeGlWidget( this, "kdeglwidget", appCore);
-    
+    string* altConfig = config.length() > 0 ? &config : NULL;
+#if KDE_VERSION >= 0x030200
+    if (!appCore->initSimulation(altConfig, &extrasDirs, splash))
+#else
+    if (!appCore->initSimulation(altConfig, &extrasDirs))
+#endif
+    {
+        exit(1);
+    }
+
     setCentralWidget(glWidget);
     initActions();
 
@@ -137,6 +170,7 @@ KdeApp::KdeApp(QWidget *parent, const char *name) : KMainWindow(parent, name)
     conf->setGroup("MainWindow");
     restoreWindowSize(conf);
     conf->setGroup(0);
+    if (fullscreen) slotFullScreen();
 
     KGlobal::config()->setGroup("Preferences");
     if (KGlobal::config()->hasKey("DistanceToScreen"))
@@ -152,8 +186,10 @@ KdeApp::KdeApp(QWidget *parent, const char *name) : KMainWindow(parent, name)
     if (menuBar()->isHidden()) toggleMenubar->setChecked(false);
 
 #if KDE_VERSION >= 0x030200
-    splash->finish(this);
-    delete splash;
+    if (splash != NULL) {
+        splash->finish(this);
+        delete splash;
+    }
 #endif
     
     // We use a timer with a null timeout value
@@ -216,13 +252,13 @@ void KdeWatcher::notifyChange(CelestiaCore * core, int property)
                      CelestiaCore::LabelFlagsChanged|
                      CelestiaCore::TimeZoneChanged)))
         kdeapp->resyncMenus();
-    else if (property & CelestiaCore::AmbientLightChanged)
+    if (property & CelestiaCore::AmbientLightChanged)
         kdeapp->resyncAmbient();
-    else if (property & CelestiaCore::FaintestChanged)
+    if (property & CelestiaCore::FaintestChanged)
         kdeapp->resyncFaintest();
-    else if (property & CelestiaCore::VerbosityLevelChanged)
+    if (property & CelestiaCore::VerbosityLevelChanged)
         kdeapp->resyncVerbosity();
-    else if (property & CelestiaCore::HistoryChanged)
+    if (property & CelestiaCore::HistoryChanged)
         kdeapp->resyncHistory();
 
     if (property == CelestiaCore::TextEnterModeChanged) {
@@ -267,6 +303,9 @@ void KdeApp::resyncMenus() {
     ((KToggleAction*)action("showStars"))->setChecked(rFlags & Renderer::ShowStars);
     ((KToggleAction*)action("showPlanets"))->setChecked(rFlags & Renderer::ShowPlanets);
     ((KToggleAction*)action("showGalaxies"))->setChecked(rFlags & Renderer::ShowGalaxies);
+    ((KToggleAction*)action("showPartialTrajectories"))->setChecked(rFlags & Renderer::ShowPartialTrajectories);
+    ((KToggleAction*)action("showNebulae"))->setChecked(rFlags & Renderer::ShowNebulae);
+    ((KToggleAction*)action("showOpenClusters"))->setChecked(rFlags & Renderer::ShowOpenClusters);
     ((KToggleAction*)action("showDiagrams"))->setChecked(rFlags & Renderer::ShowDiagrams);
     ((KToggleAction*)action("showCloudMaps"))->setChecked(rFlags & Renderer::ShowCloudMaps);
     ((KToggleAction*)action("showOrbits"))->setChecked(rFlags & Renderer::ShowOrbits);
@@ -292,7 +331,10 @@ void KdeApp::resyncMenus() {
     ((KToggleAction*)action("showMoonLabels"))->setChecked(lMode & Renderer::MoonLabels);
     ((KToggleAction*)action("showCometLabels"))->setChecked(lMode & Renderer::CometLabels);
     ((KToggleAction*)action("showConstellationLabels"))->setChecked(lMode & Renderer::ConstellationLabels);
+    ((KToggleAction*)action("showI18nConstellationLabels"))->setChecked(!(lMode & Renderer::I18nConstellationLabels));
     ((KToggleAction*)action("showGalaxyLabels"))->setChecked(lMode & Renderer::GalaxyLabels);
+    ((KToggleAction*)action("showNebulaLabels"))->setChecked(lMode & Renderer::NebulaLabels);
+    ((KToggleAction*)action("showOpenClusterLabels"))->setChecked(lMode & Renderer::OpenClusterLabels);
     ((KToggleAction*)action("showAsteroidLabels"))->setChecked(lMode & Renderer::AsteroidLabels);
     ((KToggleAction*)action("showSpacecraftLabels"))->setChecked(lMode & Renderer::SpacecraftLabels);
     ((KToggleAction*)action("showLocationLabels"))->setChecked(lMode & Renderer::LocationLabels);
@@ -322,6 +364,9 @@ void KdeApp::resyncMenus() {
     case GLContext::GLPath_NV30:
         ((KToggleAction*)action("renderPathNV30"))->setChecked(true);
         break;
+    case GLContext::GLPath_GLSL:
+        ((KToggleAction*)action("renderPathGLSL"))->setChecked(true);
+        break;
     }
 }
 
@@ -468,6 +513,15 @@ void KdeApp::initActions()
     KToggleAction* showGalaxies = new KToggleAction(i18n("Show Galaxies"), Key_U, this, SLOT(slotShowGalaxies()), actionCollection(), "showGalaxies");
     showGalaxies->setChecked(rFlags & Renderer::ShowGalaxies);
 
+    KToggleAction* showPartialTrajectories = new KToggleAction(i18n("Show Partial Trajectories"), 0, this, SLOT(slotShowPartialTrajectories()), actionCollection(), "showPartialTrajectories");
+    showPartialTrajectories->setChecked(rFlags & Renderer::ShowPartialTrajectories);
+
+    KToggleAction* showNebulae = new KToggleAction(i18n("Show Nebulae"), Key_AsciiCircum, this, SLOT(slotShowNebulae()), actionCollection(), "showNebulae");
+    showNebulae->setChecked(rFlags & Renderer::ShowNebulae);
+
+    KToggleAction* showOpenClusters = new KToggleAction(i18n("Show Open Clusters"), 0, this, SLOT(slotShowOpenClusters()), actionCollection(), "showOpenClusters");
+    showOpenClusters->setChecked(rFlags & Renderer::ShowOpenClusters);
+
     KToggleAction* showDiagrams = new KToggleAction(i18n("Show Constellations"), Key_Slash, this, SLOT(slotShowDiagrams()), actionCollection(), "showDiagrams");
     showDiagrams->setChecked(rFlags & Renderer::ShowDiagrams);
 
@@ -540,10 +594,19 @@ void KdeApp::initActions()
 
     KToggleAction* showConstellationLabels = new KToggleAction(i18n("Show Constellation Labels"), Key_Equal, this, SLOT(slotShowConstellationLabels()), actionCollection(), "showConstellationLabels");
     showConstellationLabels->setChecked(lMode & Renderer::ConstellationLabels);
-    
+
+    KToggleAction* showI18nConstellationLabels = new KToggleAction(i18n("Constellation Labels in Latin"), 0, this, SLOT(slotShowI18nConstellationLabels()), actionCollection(), "showI18nConstellationLabels");
+    showI18nConstellationLabels->setChecked(!(lMode & Renderer::I18nConstellationLabels));
+
     KToggleAction* showGalaxyLabels = new KToggleAction(i18n("Show Galaxy Labels"), Key_E, this, SLOT(slotShowGalaxyLabels()), actionCollection(), "showGalaxyLabels");
     showGalaxyLabels->setChecked(lMode & Renderer::GalaxyLabels);
 
+    KToggleAction* showNebulaLabels = new KToggleAction(i18n("Show Nebula Labels"), 0, this, SLOT(slotShowNebulaLabels()), actionCollection(), "showNebulaLabels");
+    showNebulaLabels->setChecked(lMode & Renderer::NebulaLabels);
+
+    KToggleAction* showOpenClusterLabels = new KToggleAction(i18n("Show Open Cluster Labels"), 0, this, SLOT(slotShowOpenClusterLabels()), actionCollection(), "showOpenClusterLabels");
+    showOpenClusterLabels->setChecked(lMode & Renderer::OpenClusterLabels);
+
     KToggleAction* showAsteroidLabels = new KToggleAction(i18n("Show Asteroid Labels"), Key_W, this, SLOT(slotShowAsteroidLabels()), actionCollection(), "showAsteroidLabels");
     showAsteroidLabels->setChecked(lMode & Renderer::AsteroidLabels);
 
@@ -608,6 +671,8 @@ void KdeApp::initActions()
     renderPath->setExclusiveGroup("renderPath");
     renderPath = new KToggleAction(i18n("NV30"), 0, this, SLOT(slotSetRenderPathNV30()), actionCollection(), "renderPathNV30");
     renderPath->setExclusiveGroup("renderPath");
+    renderPath = new KToggleAction(i18n("OpenGL 2.0"), 0, this, SLOT(slotSetRenderPathGLSL()), actionCollection(), "renderPathGLSL");
+    renderPath->setExclusiveGroup("renderPath");
     new KAction(i18n("Cycle OpenGL Render Path"), "reload", CTRL + Key_V, this, SLOT(slotCycleRenderPath()), actionCollection(), "cycleRenderPath");
 
     new KAction(i18n("Grab Image"), "filesave", Key_F10, this, SLOT(slotGrabImage()), actionCollection(), "grabImage");
@@ -628,7 +693,6 @@ void KdeApp::initActions()
 
     bookmarkBar = 0;
     initBookmarkBar();    
-
 }
 
 void KdeApp::initBookmarkBar() {
@@ -837,7 +901,7 @@ QString KdeApp::getOpenGLInfo() {
 
     char buf[100];
     GLint simTextures = 1;
-    if (ExtensionSupported(const_cast<char*>("GL_ARB_multitexture")))
+    if (ExtensionSupported("GL_ARB_multitexture"))
         glGetIntegerv(GL_MAX_TEXTURE_UNITS_ARB, &simTextures);
     sprintf(buf, "Max simultaneous textures: %d\n", simTextures);
     s += buf;
@@ -852,7 +916,7 @@ QString KdeApp::getOpenGLInfo() {
     {
         QString extString(ext);
         unsigned int pos = extString.find(' ', 0);
-        while (pos != string::npos)
+        while (pos != (unsigned int)string::npos)
         {
             extString.replace(pos, 1, "\n    ");
             pos = extString.find(' ', pos+5);
@@ -930,6 +994,21 @@ void KdeApp::slotShowGalaxies() {
             appCore->getRenderer()->getRenderFlags() ^ Renderer::ShowGalaxies);
 }
 
+void KdeApp::slotShowPartialTrajectories() {
+     appCore->getRenderer()->setRenderFlags(
+            appCore->getRenderer()->getRenderFlags() ^ Renderer::ShowPartialTrajectories);
+}
+
+void KdeApp::slotShowNebulae() {
+     appCore->getRenderer()->setRenderFlags(
+            appCore->getRenderer()->getRenderFlags() ^ Renderer::ShowNebulae);
+}
+
+void KdeApp::slotShowOpenClusters() {
+     appCore->getRenderer()->setRenderFlags(
+            appCore->getRenderer()->getRenderFlags() ^ Renderer::ShowOpenClusters);
+}
+
 void KdeApp::slotShowDiagrams() {
      appCore->getRenderer()->setRenderFlags(
             appCore->getRenderer()->getRenderFlags() ^ Renderer::ShowDiagrams);
@@ -1048,11 +1127,26 @@ void KdeApp::slotShowConstellationLabels() {
             appCore->getRenderer()->getLabelMode() ^ Renderer::ConstellationLabels);
 }
 
+void KdeApp::slotShowI18nConstellationLabels() {
+     appCore->getRenderer()->setLabelMode(
+            appCore->getRenderer()->getLabelMode() ^ Renderer::I18nConstellationLabels);
+}
+
 void KdeApp::slotShowGalaxyLabels() {
      appCore->getRenderer()->setLabelMode(
             appCore->getRenderer()->getLabelMode() ^ Renderer::GalaxyLabels);
 }
 
+void KdeApp::slotShowNebulaLabels() {
+     appCore->getRenderer()->setLabelMode(
+            appCore->getRenderer()->getLabelMode() ^ Renderer::NebulaLabels);
+}
+
+void KdeApp::slotShowOpenClusterLabels() {
+     appCore->getRenderer()->setLabelMode(
+            appCore->getRenderer()->getLabelMode() ^ Renderer::OpenClusterLabels);
+}
+
 void KdeApp::slotShowAsteroidLabels() {
      appCore->getRenderer()->setLabelMode(
             appCore->getRenderer()->getLabelMode() ^ Renderer::AsteroidLabels);
@@ -1220,6 +1314,10 @@ void KdeApp::slotSetRenderPathNV30() {
     if (appCore->getRenderer()->getGLContext()->getRenderPath() != GLContext::GLPath_NV30)
         appCore->getRenderer()->getGLContext()->setRenderPath(GLContext::GLPath_NV30);
 }
+void KdeApp::slotSetRenderPathGLSL() {
+    if (appCore->getRenderer()->getGLContext()->getRenderPath() != GLContext::GLPath_GLSL)
+        appCore->getRenderer()->getGLContext()->setRenderPath(GLContext::GLPath_GLSL);
+}
 
 void KdeApp::slotCycleRenderPath() {
     appCore->charEntered('\026');
