@@ -68,7 +68,7 @@ friend void KdeWatcher::notifyChange(CelestiaCore*, int);
 
 public:
     /** construtor */
-    KdeApp(QWidget* parent=0, const char *name=0);
+    KdeApp(std::string config, std::string dir, std::vector<std::string> extrasDirs, bool fullscreen, bool disableSplash);
     /** destructor */
     ~KdeApp() {};
 
@@ -111,6 +111,9 @@ public slots:
     void slotShowStars();
     void slotShowPlanets();
     void slotShowGalaxies();
+    void slotShowNebulae();
+    void slotShowOpenClusters();
+    void slotShowPartialTrajectories();
     void slotShowDiagrams();
     void slotShowCloudMaps();
 
@@ -137,7 +140,10 @@ public slots:
     void slotShowMoonLabels();
     void slotShowCometLabels();
     void slotShowConstellationLabels();
+    void slotShowI18nConstellationLabels();
     void slotShowGalaxyLabels();
+    void slotShowNebulaLabels();
+    void slotShowOpenClusterLabels();
     void slotShowAsteroidLabels();
     void slotShowSpacecraftLabels();
     void slotShowLocationLabels();
@@ -173,6 +179,7 @@ public slots:
     void slotSetRenderPathNvCombinerARBVP();
     void slotSetRenderPathARBFPARBVP();
     void slotSetRenderPathNV30();
+    void slotSetRenderPathGLSL();
     void slotCycleRenderPath();
 
     void slotCelestialBrowser();
