@@ -49,14 +49,10 @@
 #include <math.h>
 #include <vector>
 
-KdeGlWidget::KdeGlWidget(  QWidget* parent, const char* name, CelestiaCore* core )
+KdeGlWidget::KdeGlWidget(  QWidget* parent, const char* name, CelestiaCore* core)
     : QGLWidget( parent, name )
 {
-    if (chdir(CONFIG_DATA_DIR) == -1)
-    {
-//        cerr << "Cannot chdir to '" << CONFIG_DATA_DIR <<
-//            "', probably due to improper installation\n";
-    }
+
     
     actionColl = ((KdeApp*)parent)->actionCollection();
 
@@ -73,12 +69,6 @@ KdeGlWidget::KdeGlWidget(  QWidget* parent, const char* name, CelestiaCore* core
     appCore->setCursorHandler(this);
     
     lastX = lastY = 0;
-
-    if (!appCore->initSimulation())
-    {
-        exit(1);
-    }
-
 }
 
 
@@ -155,6 +145,8 @@ void KdeGlWidget::initializeGL()
         ((KToggleAction*)(((KdeApp*)parentWidget())->action("renderPathARBFPARBVP")))->setEnabled(false);
     if (!appCore->getRenderer()->getGLContext()->renderPathSupported(GLContext::GLPath_NV30))
         ((KToggleAction*)(((KdeApp*)parentWidget())->action("renderPathNV30")))->setEnabled(false);
+    if (!appCore->getRenderer()->getGLContext()->renderPathSupported(GLContext::GLPath_GLSL))
+        ((KToggleAction*)(((KdeApp*)parentWidget())->action("renderPathGLSL")))->setEnabled(false);
 
     if (KGlobal::config()->hasKey("RenderPath")) {
        GLContext::GLRenderPath path = (GLContext::GLRenderPath)KGlobal::config()->readNumEntry("RenderPath");
@@ -188,12 +180,16 @@ void KdeGlWidget::initializeGL()
     case GLContext::GLPath_NV30:
         ((KToggleAction*)(((KdeApp*)parentWidget())->action("renderPathNV30")))->setChecked(true);
         break;
+    case GLContext::GLPath_GLSL:
+        ((KToggleAction*)(((KdeApp*)parentWidget())->action("renderPathGLSL")))->setChecked(true);
+        break;
     }
 
     KGlobal::config()->setGroup(0);
 
     QPaintDeviceMetrics pdm(this);
     appCore->setScreenDpi(pdm.logicalDpiY());
+
 }
 
 void KdeGlWidget::resizeGL( int w, int h )
@@ -261,11 +257,11 @@ void KdeGlWidget::wheelEvent( QWheelEvent* w )
 {
     if (w->delta() > 0 )
     {
-        appCore->mouseWheel(1.0f, 0);
+        appCore->mouseWheel(-1.0f, 0);
     }
     else if (w->delta() < 0)
     {
-        appCore->mouseWheel(-1.0f, 0);
+        appCore->mouseWheel(1.0f, 0);
     }
 }
 
