@@ -73,6 +73,10 @@ KdePreferencesDialog::KdePreferencesDialog(QWidget* parent, CelestiaCore* core)
     actionColl->action("showStars")->connect(showStarsCheck, SIGNAL(clicked()), SLOT(activate()));
     showStarsCheck->setChecked(renderFlags & Renderer::ShowStars);
 
+    QCheckBox* showAutoMagCheck = new QCheckBox(i18n("Auto Magnitudes"), showGroup);
+    actionColl->action("showAutoMag")->connect(showAutoMagCheck, SIGNAL(clicked()), SLOT(activate()));
+    showAutoMagCheck->setChecked(renderFlags & Renderer::ShowAutoMag);
+
     QCheckBox* showPlanetsCheck = new QCheckBox(i18n("Planets"), showGroup);
     actionColl->action("showPlanets")->connect(showPlanetsCheck, SIGNAL(clicked()), SLOT(activate()));
     showPlanetsCheck->setChecked(renderFlags & Renderer::ShowPlanets);
@@ -81,42 +85,58 @@ KdePreferencesDialog::KdePreferencesDialog(QWidget* parent, CelestiaCore* core)
     actionColl->action("showGalaxies")->connect(showGalaxiesCheck, SIGNAL(clicked()), SLOT(activate()));
     showGalaxiesCheck->setChecked(renderFlags & Renderer::ShowGalaxies);
 
-    QCheckBox* showDiagramsCheck = new QCheckBox(i18n("Constellations"), showGroup);
-    actionColl->action("showDiagrams")->connect(showDiagramsCheck, SIGNAL(clicked()), SLOT(activate()));
-    showDiagramsCheck->setChecked(renderFlags & Renderer::ShowDiagrams);
+    QCheckBox* showNebulaeCheck = new QCheckBox(i18n("Nebulae"), showGroup);
+    actionColl->action("showNebulae")->connect(showNebulaeCheck, SIGNAL(clicked()), SLOT(activate()));
+    showNebulaeCheck->setChecked(renderFlags & Renderer::ShowNebulae);
 
-    QCheckBox* showCloudMapsCheck = new QCheckBox(i18n("Clouds"), showGroup);
-    actionColl->action("showCloudMaps")->connect(showCloudMapsCheck, SIGNAL(clicked()), SLOT(activate()));
-    showCloudMapsCheck->setChecked(renderFlags & Renderer::ShowCloudMaps);
-
-    QCheckBox* showOrbitsCheck = new QCheckBox(i18n("Orbits"), showGroup);
-    actionColl->action("showOrbits")->connect(showOrbitsCheck, SIGNAL(clicked()), SLOT(activate()));
-    showOrbitsCheck->setChecked(renderFlags & Renderer::ShowOrbits);
-
-    QCheckBox* showCelestialSphereCheck = new QCheckBox(i18n("Celestial Grid"), showGroup);
-    actionColl->action("showCelestialSphere")->connect(showCelestialSphereCheck, SIGNAL(clicked()), SLOT(activate()));
-    showCelestialSphereCheck->setChecked(renderFlags & Renderer::ShowCelestialSphere);
-
-    QCheckBox* showNightMapsCheck = new QCheckBox(i18n("Night Side Lights"), showGroup);
-    actionColl->action("showNightMaps")->connect(showNightMapsCheck, SIGNAL(clicked()), SLOT(activate()));
-    showNightMapsCheck->setChecked(renderFlags & Renderer::ShowNightMaps);
-
-    QCheckBox* showMarkersCheck = new QCheckBox(i18n("Markers"), showGroup);
-    actionColl->action("showMarkers")->connect(showMarkersCheck, SIGNAL(clicked()), SLOT(activate()));
-    showMarkersCheck->setChecked(renderFlags & Renderer::ShowMarkers);
+    QCheckBox* showOpenClustersCheck = new QCheckBox(i18n("Open Clusters"), showGroup);
+    actionColl->action("showOpenClusters")->connect(showOpenClustersCheck, SIGNAL(clicked()), SLOT(activate()));
+    showOpenClustersCheck->setChecked(renderFlags & Renderer::ShowOpenClusters);
 
     QCheckBox* showAtmospheresCheck = new QCheckBox(i18n("Atmospheres"), showGroup);
     actionColl->action("showAtmospheres")->connect(showAtmospheresCheck, SIGNAL(clicked()), SLOT(activate()));
     showAtmospheresCheck->setChecked(renderFlags & Renderer::ShowAtmospheres);
 
-    QCheckBox* showSmoothLinesCheck = new QCheckBox(i18n("Smooth Orbit Lines"), showGroup);
-    actionColl->action("showSmoothLines")->connect(showSmoothLinesCheck, SIGNAL(clicked()), SLOT(activate()));
-    showSmoothLinesCheck->setChecked(renderFlags & Renderer::ShowSmoothLines);
+    QCheckBox* showCloudMapsCheck = new QCheckBox(i18n("Clouds"), showGroup);
+    actionColl->action("showCloudMaps")->connect(showCloudMapsCheck, SIGNAL(clicked()), SLOT(activate()));
+    showCloudMapsCheck->setChecked(renderFlags & Renderer::ShowCloudMaps);
+
+    QCheckBox* showNightMapsCheck = new QCheckBox(i18n("Night Side Lights"), showGroup);
+    actionColl->action("showNightMaps")->connect(showNightMapsCheck, SIGNAL(clicked()), SLOT(activate()));
+    showNightMapsCheck->setChecked(renderFlags & Renderer::ShowNightMaps);
 
     QCheckBox* showEclipseShadowsCheck = new QCheckBox(i18n("Eclipse Shadows"), showGroup);
     actionColl->action("showEclipseShadows")->connect(showEclipseShadowsCheck, SIGNAL(clicked()), SLOT(activate()));
     showEclipseShadowsCheck->setChecked(renderFlags & Renderer::ShowEclipseShadows);
 
+    QCheckBox* showCometTailsCheck = new QCheckBox(i18n("Comet Tails"), showGroup);
+    actionColl->action("showCometTails")->connect(showCometTailsCheck, SIGNAL(clicked()), SLOT(activate()));
+    showCometTailsCheck->setChecked(renderFlags & Renderer::ShowCometTails);
+
+    QCheckBox* showOrbitsCheck = new QCheckBox(i18n("Orbits"), showGroup);
+    actionColl->action("showOrbits")->connect(showOrbitsCheck, SIGNAL(clicked()), SLOT(activate()));
+    showOrbitsCheck->setChecked(renderFlags & Renderer::ShowOrbits);
+
+    QCheckBox* showPartialTrajectoriesCheck = new QCheckBox(i18n("Partial Trajectories"), showGroup);
+    actionColl->action("showPartialTrajectories")->connect(showPartialTrajectoriesCheck, SIGNAL(clicked()), SLOT(activate()));
+    showPartialTrajectoriesCheck->setChecked(renderFlags & Renderer::ShowPartialTrajectories);
+
+    QCheckBox* showSmoothLinesCheck = new QCheckBox(i18n("Smooth Orbit Lines"), showGroup);
+    actionColl->action("showSmoothLines")->connect(showSmoothLinesCheck, SIGNAL(clicked()), SLOT(activate()));
+    showSmoothLinesCheck->setChecked(renderFlags & Renderer::ShowSmoothLines);
+
+    QCheckBox* showCelestialSphereCheck = new QCheckBox(i18n("Celestial Grid"), showGroup);
+    actionColl->action("showCelestialSphere")->connect(showCelestialSphereCheck, SIGNAL(clicked()), SLOT(activate()));
+    showCelestialSphereCheck->setChecked(renderFlags & Renderer::ShowCelestialSphere);
+
+    QCheckBox* showDiagramsCheck = new QCheckBox(i18n("Constellations"), showGroup);
+    actionColl->action("showDiagrams")->connect(showDiagramsCheck, SIGNAL(clicked()), SLOT(activate()));
+    showDiagramsCheck->setChecked(renderFlags & Renderer::ShowDiagrams);
+
+    QCheckBox* showMarkersCheck = new QCheckBox(i18n("Markers"), showGroup);
+    actionColl->action("showMarkers")->connect(showMarkersCheck, SIGNAL(clicked()), SLOT(activate()));
+    showMarkersCheck->setChecked(renderFlags & Renderer::ShowMarkers);
+
     QCheckBox* showRingShadowsCheck = new QCheckBox(i18n("Ring Shadows"), showGroup);
     actionColl->action("showRingShadows")->connect(showRingShadowsCheck, SIGNAL(clicked()), SLOT(activate()));
     showRingShadowsCheck->setChecked(renderFlags & Renderer::ShowRingShadows);
@@ -125,14 +145,6 @@ KdePreferencesDialog::KdePreferencesDialog(QWidget* parent, CelestiaCore* core)
     actionColl->action("showBoundaries")->connect(showBoundariesCheck, SIGNAL(clicked()), SLOT(activate()));
     showBoundariesCheck->setChecked(renderFlags & Renderer::ShowBoundaries);
 
-    QCheckBox* showAutoMagCheck = new QCheckBox(i18n("Auto Magnitudes"), showGroup);
-    actionColl->action("showAutoMag")->connect(showAutoMagCheck, SIGNAL(clicked()), SLOT(activate()));
-    showAutoMagCheck->setChecked(renderFlags & Renderer::ShowAutoMag);
-
-    QCheckBox* showCometTailsCheck = new QCheckBox(i18n("Comet Tails"), showGroup);
-    actionColl->action("showCometTails")->connect(showCometTailsCheck, SIGNAL(clicked()), SLOT(activate()));
-    showCometTailsCheck->setChecked(renderFlags & Renderer::ShowCometTails);
-
 
     QVBox* vbox1 = new QVBox(renderFrame);
     int labelMode = appCore->getRenderer()->getLabelMode();
@@ -187,33 +199,48 @@ KdePreferencesDialog::KdePreferencesDialog(QWidget* parent, CelestiaCore* core)
     showConstellationLabelsCheck->setChecked(labelMode & Renderer::ConstellationLabels);
     labelGroupLayout->addWidget(showConstellationLabelsCheck, 6, 1);
 
+    QCheckBox* showI18nConstellationLabelsCheck = new QCheckBox(i18n("Constellations in Latin"), labelGroup);
+    actionColl->action("showI18nConstellationLabels")->connect(showI18nConstellationLabelsCheck, SIGNAL(clicked()), SLOT(activate()));
+    showI18nConstellationLabelsCheck->setChecked(!(labelMode & Renderer::I18nConstellationLabels));
+    labelGroupLayout->addWidget(showI18nConstellationLabelsCheck, 7, 1);
+
     QCheckBox* showGalaxyLabelsCheck = new QCheckBox(i18n("Galaxies"), labelGroup);
     actionColl->action("showGalaxyLabels")->connect(showGalaxyLabelsCheck, SIGNAL(clicked()), SLOT(activate()));
     showGalaxyLabelsCheck->setChecked(labelMode & Renderer::GalaxyLabels);
-    labelGroupLayout->addWidget(showGalaxyLabelsCheck, 7, 1);
+    labelGroupLayout->addWidget(showGalaxyLabelsCheck, 8, 1);
+
+    QCheckBox* showNebulaLabelsCheck = new QCheckBox(i18n("Nebulae"), labelGroup);
+    actionColl->action("showNebulaLabels")->connect(showNebulaLabelsCheck, SIGNAL(clicked()), SLOT(activate()));
+    showNebulaLabelsCheck->setChecked(labelMode & Renderer::NebulaLabels);
+    labelGroupLayout->addWidget(showNebulaLabelsCheck, 9, 1);
+
+    QCheckBox* showOpenClusterLabelsCheck = new QCheckBox(i18n("Open Clusters"), labelGroup);
+    actionColl->action("showOpenClusterLabels")->connect(showOpenClusterLabelsCheck, SIGNAL(clicked()), SLOT(activate()));
+    showOpenClusterLabelsCheck->setChecked(labelMode & Renderer::OpenClusterLabels);
+    labelGroupLayout->addWidget(showOpenClusterLabelsCheck, 10, 1);
 
     QCheckBox* showAsteroidOrbitsCheck = new QCheckBox("", labelGroup);
     actionColl->action("showAsteroidOrbits")->connect(showAsteroidOrbitsCheck, SIGNAL(clicked()), SLOT(activate()));
     showAsteroidOrbitsCheck->setChecked(orbitMask & Body::Asteroid);
-    labelGroupLayout->addWidget(showAsteroidOrbitsCheck, 8, 0, Qt::AlignHCenter);
+    labelGroupLayout->addWidget(showAsteroidOrbitsCheck, 11, 0, Qt::AlignHCenter);
     QCheckBox* showAsteroidLabelsCheck = new QCheckBox(i18n("Asteroids"), labelGroup);
     actionColl->action("showAsteroidLabels")->connect(showAsteroidLabelsCheck, SIGNAL(clicked()), SLOT(activate()));
     showAsteroidLabelsCheck->setChecked(labelMode & Renderer::AsteroidLabels);
-    labelGroupLayout->addWidget(showAsteroidLabelsCheck, 8, 1);
+    labelGroupLayout->addWidget(showAsteroidLabelsCheck, 11, 1);
 
     QCheckBox* showSpacecraftOrbitsCheck = new QCheckBox("", labelGroup);
     actionColl->action("showSpacecraftOrbits")->connect(showSpacecraftOrbitsCheck, SIGNAL(clicked()), SLOT(activate()));
     showSpacecraftOrbitsCheck->setChecked(orbitMask & Body::Spacecraft);
-    labelGroupLayout->addWidget(showSpacecraftOrbitsCheck, 9, 0, Qt::AlignHCenter);
+    labelGroupLayout->addWidget(showSpacecraftOrbitsCheck, 12, 0, Qt::AlignHCenter);
     QCheckBox* showSpacecraftLabelsCheck = new QCheckBox(i18n("Spacecrafts"), labelGroup);
     actionColl->action("showSpacecraftLabels")->connect(showSpacecraftLabelsCheck, SIGNAL(clicked()), SLOT(activate()));
     showSpacecraftLabelsCheck->setChecked(labelMode & Renderer::SpacecraftLabels);
-    labelGroupLayout->addWidget(showSpacecraftLabelsCheck, 9, 1);
+    labelGroupLayout->addWidget(showSpacecraftLabelsCheck, 12, 1);
 
     QCheckBox* showLocationLabelsCheck = new QCheckBox(i18n("Locations"), labelGroup);
     actionColl->action("showLocationLabels")->connect(showLocationLabelsCheck, SIGNAL(clicked()), SLOT(activate()));
     showLocationLabelsCheck->setChecked(labelMode & Renderer::LocationLabels);
-    labelGroupLayout->addWidget(showLocationLabelsCheck, 10, 1);
+    labelGroupLayout->addWidget(showLocationLabelsCheck, 13, 1);
 
     QSpacerItem* spacer = new QSpacerItem( 151, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
     labelGroupLayout->addItem( spacer, 0, 2 );
@@ -443,6 +470,8 @@ KdePreferencesDialog::KdePreferencesDialog(QWidget* parent, CelestiaCore* core)
         renderPathCombo->insertItem(i18n("ARBFP ARBVP"));
     if (appCore->getRenderer()->getGLContext()->renderPathSupported(GLContext::GLPath_NV30))
         renderPathCombo->insertItem(i18n("NV30"));
+    if (appCore->getRenderer()->getGLContext()->renderPathSupported(GLContext::GLPath_GLSL))
+        renderPathCombo->insertItem(i18n("OpenGL 2.0"));
 
     connect(renderPathCombo, SIGNAL(activated(int)), SLOT(slotRenderPath(int)));
 
@@ -708,6 +737,9 @@ void KdePreferencesDialog::setRenderPathLabel() {
     case GLContext::GLPath_NV30:
         renderPathLabel->setText(i18n("<b>NV_fragment_program and ARB_vertex_program extensions</b>"));
         break;
+    case GLContext::GLPath_GLSL:
+        renderPathLabel->setText(i18n("<b>OpenGL 2.0 Shading Language</b>"));
+        break;
     }
 }
 
