@@ -2,6 +2,7 @@
 // Microsoft Developer Studio generated include file.
 // Used by Celestia.rc
 //
+#define VERSION_STRING                  "1.4.1"
 #define IDR_MENU1                       101
 #define IDD_ABOUT                       102
 #define IDI_CELESTIA_ICON               103
@@ -103,6 +104,7 @@
 #define IDC_ORGANIZE_BOOKMARKS_RENAME   1060
 #define IDC_ORGANIZE_BOOKMARKS_DELETE   1061
 #define IDC_NEWBOOKMARK                 1062
+#define IDC_SHOWNEBULAE                 1063
 #define IDC_LABELASTEROIDS              1064
 #define IDC_LABELSPACECRAFT             1065
 #define IDC_SHOWMARKERS                 1066
@@ -113,6 +115,8 @@
 #define IDC_ECLIPSES_LIST               1071
 #define IDC_LABELCOMETS                 1072
 #define IDC_COMETORBITS                 1073
+#define IDC_LABELNEBULAE                1074
+#define IDC_LABELOPENCLUSTERS           1075
 #define IDCOMPUTE                       1078
 #define IDC_DATEFROM                    1079
 #define IDC_ECLIPSEFROM                 1079
@@ -140,6 +144,7 @@
 #define IDC_SLIDER_FEATURE_SIZE         1150
 #define IDC_EDIT_FEATURE_SIZE           1151
 #define IDC_CELESTIALINK                1152
+#define IDC_COMBOBOX_TIMEZONE           1153
 #define ID_SELECTSOL                    40001
 #define ID_GOTOSELECTION                40002
 #define ID_FOLLOWSELECTION              40003
