@@ -14,6 +14,7 @@
 #include <set>
 #include <windows.h>
 #include <commctrl.h>
+#include <cstring>
 #include "winstarbrowser.h"
 
 #include "res/resource.h"
@@ -163,7 +164,11 @@ FindStars(const StarDatabase& stardb, Pred pred, int nStars)
     // up the list indiscriminately.
     int i = 0;
     for (i = 0; i < nStars; i++)
-        firstStars.insert(stardb.getStar(i));
+    {
+        Star* star = stardb.getStar(i);
+        if (star->getVisibility())
+            firstStars.insert(star);
+    }
 
     // From here on, only add a star to the set if it's
     // a better match than the worst matching star already
@@ -172,7 +177,7 @@ FindStars(const StarDatabase& stardb, Pred pred, int nStars)
     for (; i < totalStars; i++)
     {
         Star* star = stardb.getStar(i);
-        if (pred(star, lastStar))
+        if (star->getVisibility() && pred(star, lastStar))
         {
             firstStars.insert(star);
             firstStars.erase(--firstStars.end());
@@ -308,12 +313,7 @@ int CALLBACK StarBrowserCompareFunc(LPARAM lParam0, LPARAM lParam1,
         return (int) sign(star0->getAbsoluteMagnitude() - star1->getAbsoluteMagnitude());
 
     case 4:
-        if (star0->getStellarClass() < star1->getStellarClass())
-            return -1;
-        else if (star1->getStellarClass() < star0->getStellarClass())
-            return 1;
-        else
-            return 0;
+        return strcmp(star0->getSpectralType(), star1->getSpectralType());
 
     default:
         return 0;
@@ -362,7 +362,9 @@ void StarBrowserDisplayItem(LPNMLVDISPINFOA nm, StarBrowser* browser)
         break;
 
     case 4:
-        star->getStellarClass().str(callbackScratch, sizeof(callbackScratch));
+        strncpy(callbackScratch, star->getSpectralType(),
+                sizeof(callbackScratch));
+        callbackScratch[sizeof(callbackScratch) - 1] = '\0';
         nm->item.pszText = callbackScratch;
         break;
     }
