@@ -14,7 +14,9 @@
 #include <cstdarg>
 
 #ifndef _WIN32
+#ifndef MACOSX_PB
 #include <config.h>
+#endif /* MACOSX_PB */
 #endif /* _WIN32 */
 
 static int debugVerbosity = 0;
