@@ -13,9 +13,24 @@
 #define _UTIL_H_
 
 #include <string>
+#include <vector>
 #include <iostream>
 #include <functional>
 
+#ifndef min
+#define min(a, b) ((a) < (b) ? (a) : (b))
+#endif
+
+#ifndef max
+#define max(a, b) ((a) < (b) ? (b) : (a))
+#endif
+				      
+#ifdef _WIN32
+#define _(s) s
+#else
+#define _(s) gettext(s)
+#endif
+
 extern int compareIgnoringCase(const std::string& s1, const std::string& s2);
 extern int compareIgnoringCase(const std::string& s1, const std::string& s2, int n);
 
